==> mastapy-14.0.0rc3-py3-none-any.whl: mastapy/_private/utility/file_access_helpers/_1871.py <==
"""TextFileDelimiterOptions"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal.python_net import (
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
    python_net_import,
)
from mastapy._private._internal import conversion, utility
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException

_TEXT_FILE_DELIMITER_OPTIONS = python_net_import(
    "SMT.MastaAPI.Utility.FileAccessHelpers", "TextFileDelimiterOptions"
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    Self = TypeVar("Self", bound="TextFileDelimiterOptions")
    CastSelf = TypeVar(
        "CastSelf", bound="TextFileDelimiterOptions._Cast_TextFileDelimiterOptions"
    )


__docformat__ = "restructuredtext en"
__all__ = ("TextFileDelimiterOptions",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_TextFileDelimiterOptions:
    """Special nested class for casting TextFileDelimiterOptions to subclasses."""

    __parent__: "TextFileDelimiterOptions"

    @property
    def text_file_delimiter_options(self: "CastSelf") -> "TextFileDelimiterOptions":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class TextFileDelimiterOptions(_0.APIBase):
    """TextFileDelimiterOptions

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _TEXT_FILE_DELIMITER_OPTIONS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def other(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get(self.wrapped, "Other")

        if temp is None:
            return ""

        return temp

    @other.setter
    @enforce_parameter_types
    def other(self: "Self", value: "str") -> None:
        pythonnet_property_set(
            self.wrapped, "Other", str(value) if value is not None else ""
        )

    @property
    def treat_consecutive_delimiters_as_one(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "TreatConsecutiveDelimitersAsOne")

        if temp is None:
            return False

        return temp

    @treat_consecutive_delimiters_as_one.setter
    @enforce_parameter_types
    def treat_consecutive_delimiters_as_one(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "TreatConsecutiveDelimitersAsOne",
            bool(value) if value is not None else False,
        )

    @property
    def use_comma(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "UseComma")

        if temp is None:
            return False

        return temp

    @use_comma.setter
    @enforce_parameter_types
    def use_comma(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped, "UseComma", bool(value) if value is not None else False
        )

    @property
    def use_semi_colon(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "UseSemiColon")

        if temp is None:
            return False

        return temp

    @use_semi_colon.setter
    @enforce_parameter_types
    def use_semi_colon(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped, "UseSemiColon", bool(value) if value is not None else False
        )

    @property
    def use_space(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "UseSpace")

        if temp is None:
            return False

        return temp

    @use_space.setter
    @enforce_parameter_types
    def use_space(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped, "UseSpace", bool(value) if value is not None else False
        )

    @property
    def use_tab(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "UseTab")

        if temp is None:
            return False

        return temp

    @use_tab.setter
    @enforce_parameter_types
    def use_tab(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped, "UseTab", bool(value) if value is not None else False
        )

    @property
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ReportNames")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped, "OutputDefaultReportTo", file_path if file_path else ""
        )

    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetDefaultReportWithEncodedImages"
        )
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped, "OutputActiveReportTo", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped, "OutputActiveReportAsTextTo", file_path if file_path else ""
        )

    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetActiveReportWithEncodedImages"
        )
        return method_result

    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportTo",
            report_name if report_name else "",
            file_path if file_path else "",
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsMastaReport",
            report_name if report_name else "",
            file_path if file_path else "",
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsTextTo",
            report_name if report_name else "",
            file_path if file_path else "",
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = pythonnet_method_call(
            self.wrapped,
            "GetNamedReportWithEncodedImages",
            report_name if report_name else "",
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_TextFileDelimiterOptions":
        """Cast to another type.

        Returns:
            _Cast_TextFileDelimiterOptions
        """
        return _Cast_TextFileDelimiterOptions(self)

==> mastapy-14.0.1b1-py3-none-any.whl: mastapy/_private/utility/file_access_helpers/_1871.py <==
"""TextFileDelimiterOptions"""

from __future__ import annotations

from typing import ClassVar, TYPE_CHECKING

from mastapy._private import _0
from mastapy._private._internal import conversion, utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

_TEXT_FILE_DELIMITER_OPTIONS = python_net_import(
    "SMT.MastaAPI.Utility.FileAccessHelpers", "TextFileDelimiterOptions"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar("Self", bound="TextFileDelimiterOptions")
    CastSelf = TypeVar(
        "CastSelf", bound="TextFileDelimiterOptions._Cast_TextFileDelimiterOptions"
    )


__docformat__ = "restructuredtext en"
__all__ = ("TextFileDelimiterOptions",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_TextFileDelimiterOptions:
    """Special nested class for casting TextFileDelimiterOptions to subclasses."""

    __parent__: "TextFileDelimiterOptions"

    @property
    def text_file_delimiter_options(self: "CastSelf") -> "TextFileDelimiterOptions":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class TextFileDelimiterOptions(_0.APIBase):
    """TextFileDelimiterOptions

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _TEXT_FILE_DELIMITER_OPTIONS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def other(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get(self.wrapped, "Other")

        if temp is None:
            return ""

        return temp

    @other.setter
    @enforce_parameter_types
    def other(self: "Self", value: "str") -> None:
        pythonnet_property_set(
            self.wrapped, "Other", str(value) if value is not None else ""
        )

    @property
    def treat_consecutive_delimiters_as_one(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "TreatConsecutiveDelimitersAsOne")

        if temp is None:
            return False

        return temp

    @treat_consecutive_delimiters_as_one.setter
    @enforce_parameter_types
    def treat_consecutive_delimiters_as_one(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "TreatConsecutiveDelimitersAsOne",
            bool(value) if value is not None else False,
        )

    @property
    def use_comma(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "UseComma")

        if temp is None:
            return False

        return temp

    @use_comma.setter
    @enforce_parameter_types
    def use_comma(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped, "UseComma", bool(value) if value is not None else False
        )

    @property
    def use_semi_colon(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "UseSemiColon")

        if temp is None:
            return False

        return temp

    @use_semi_colon.setter
    @enforce_parameter_types
    def use_semi_colon(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped, "UseSemiColon", bool(value) if value is not None else False
        )

    @property
    def use_space(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "UseSpace")

        if temp is None:
            return False

        return temp

    @use_space.setter
    @enforce_parameter_types
    def use_space(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped, "UseSpace", bool(value) if value is not None else False
        )

    @property
    def use_tab(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "UseTab")

        if temp is None:
            return False

        return temp

    @use_tab.setter
    @enforce_parameter_types
    def use_tab(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped, "UseTab", bool(value) if value is not None else False
        )

    @property
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ReportNames")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped, "OutputDefaultReportTo", file_path if file_path else ""
        )

    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetDefaultReportWithEncodedImages"
        )
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped, "OutputActiveReportTo", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped, "OutputActiveReportAsTextTo", file_path if file_path else ""
        )

    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetActiveReportWithEncodedImages"
        )
        return method_result

    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportTo",
            report_name if report_name else "",
            file_path if file_path else "",
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsMastaReport",
            report_name if report_name else "",
            file_path if file_path else "",
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsTextTo",
            report_name if report_name else "",
            file_path if file_path else "",
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = pythonnet_method_call(
            self.wrapped,
            "GetNamedReportWithEncodedImages",
            report_name if report_name else "",
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_TextFileDelimiterOptions":
        """Cast to another type.

        Returns:
            _Cast_TextFileDelimiterOptions
        """
        return _Cast_TextFileDelimiterOptions(self)
